@@ -1,6 +1,6 @@
 from os import PathLike
 from types import FunctionType
-from typing import Protocol, Union, AsyncIterable, List, Awaitable, AsyncGenerator, Any, Tuple, Callable, Iterable
+from typing import Protocol, Union, AsyncIterable, List, Awaitable, AsyncGenerator, Tuple, Callable, Iterable
 
 from .notebook import Notebook
 
